# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['polyglot_tokenizer', 'polyglot_tokenizer.tests']

package_data = \
{'': ['*'], 'polyglot_tokenizer': ['data/*']}

install_requires = \
['pbr>=2.0,<3.0', 'six>=1.12,<2.0']

entry_points = \
{'console_scripts': ['polyglot-tokenizer = polyglot_tokenizer:main']}

setup_kwargs = {
    'name': 'polyglot-tokenizer',
    'version': '2.0.1.4',
    'description': "Tokenizer for world's most spoken languages and social media texts like Facebook, Twitter etc.",
    'long_description': 'Polyglot Tokenizer\n==================\n\n\nTokenizer for world\'s most spoken languages and social media texts like Facebook, Twitter etc.\n\n\nInstallation\n------------\n\n::\n\n    pip install polyglot-tokenizer\n\nExamples\n--------\n\nWithin Python\n^^^^^^^^^^^^^\n\n\n.. code:: python\n\n    >>> from __future__ import unicode_literals\n    >>> from polyglot_tokenizer import Tokenizer\n    >>> tk = Tokenizer(lang=\'en\', smt=True) #smt is a flag for social-media-text\n    >>> text = "RT @BJP_RSS Crack down on Black money.India slides to 75th slot on Swiss bank money list #ModiForeignAchievements @RituRathaur https://t.c\xe2\x80\xa6"\n    >>> tk.tokenize(text)\n    [\'RT\', \'@BJP_RSS\', \'Crack\', \'down\', \'on\', \'Black\', \'money\', \'.\', \'India\', \'slides\', \'to\', \'75th\', \'slot\', \'on\', \'Swiss\', \'bank\', \'money\', \'list\', \'#ModiForeignAchievements\', \'@RituRathaur\', \'https://t.c\xe2\x80\xa6\']\n    >>> tk = Tokenizer(lang=\'hi\')\n    >>> tk.tokenize("22 \xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xb2 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\x82\xe0\xa4\xac\xe0\xa5\x87 \xe0\xa4\x87\xe0\xa4\x82\xe0\xa4\xa4\xe0\xa4\x9c\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xac\xe0\xa4\xbe\xe0\xa4\xa6 \xe0\xa4\x86\xe0\xa4\x96\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\xb9\xe0\xa5\x89\xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa5\x81\xe0\xa4\xa1 \xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x9f\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b \xe0\xa4\xa1\xe0\xa4\xbf\xe0\xa4\x95\xe0\xa5\x88\xe0\xa4\xaa\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b \xe0\xa4\x95\xe0\xa5\x8b \xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80 \xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x80 \xe0\xa4\x91\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x95\xe0\xa4\xb0 \xe0\xa4\x9f\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa5\x89\xe0\xa4\xab\xe0\xa5\x80"\n    ...             " \xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2 \xe0\xa4\x9a\xe0\xa5\x81\xe0\xa4\x95\xe0\xa5\x80 \xe0\xa4\xb9\xe0\xa5\x88\xe0\xa5\xa4 \xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xaf\xe0\xa5\x87 \xe0\xa4\x85\xe0\xa4\xb5\xe0\xa5\x89\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1 \xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80 \xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae \xe2\x80\x98\xe0\xa4\xa6 \xe0\xa4\xb0\xe0\xa5\x87\xe0\xa4\xb5\xe0\xa5\x87\xe0\xa4\xa8\xe0\xa5\x87\xe0\xa4\x82\xe0\xa4\x9f\xe2\x80\x99 \xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xb9\xe0\xa5\x8d\xe0\xa4\xaf\xe0\xa5\x82\xe0\xa4\x9c \xe0\xa4\x97\xe0\xa5\x8d\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\xb8 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\xa6\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa4\xbe, \xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8 \xe0\xa4\x89\xe0\xa4\xa8\xe0\xa4\x95\xe0\xa5\x87"\n    ...             " \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xb0\xe0\xa5\x8b\xe0\xa4\xb2 \xe0\xa4\xa8\xe0\xa4\xbf\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe \xe0\xa4\x86\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xa8 \xe0\xa4\xa8\xe0\xa4\xb9\xe0\xa5\x80\xe0\xa4\x82 \xe0\xa4\xa5\xe0\xa4\xbe\xe0\xa5\xa4")\n    [\'22\', \'\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xb2\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\x82\xe0\xa4\xac\xe0\xa5\x87\', \'\xe0\xa4\x87\xe0\xa4\x82\xe0\xa4\xa4\xe0\xa4\x9c\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xac\xe0\xa4\xbe\xe0\xa4\xa6\', \'\xe0\xa4\x86\xe0\xa4\x96\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\xb9\xe0\xa5\x89\xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa5\x81\xe0\xa4\xa1\', \'\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x9f\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b\', \'\xe0\xa4\xa1\xe0\xa4\xbf\xe0\xa4\x95\xe0\xa5\x88\xe0\xa4\xaa\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\', \'\xe0\xa4\x95\xe0\xa5\x8b\', \'\xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80\', \'\xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x80\', \'\xe0\xa4\x91\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x95\xe0\xa4\xb0\', \'\xe0\xa4\x9f\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa5\x89\xe0\xa4\xab\xe0\xa5\x80\', \'\xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\', \'\xe0\xa4\x9a\xe0\xa5\x81\xe0\xa4\x95\xe0\xa5\x80\', \'\xe0\xa4\xb9\xe0\xa5\x88\', \'\xe0\xa5\xa4\', \'\xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xaf\xe0\xa5\x87\', \'\xe0\xa4\x85\xe0\xa4\xb5\xe0\xa5\x89\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\', \'\xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80\', \'\xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae\', "\'", \'\xe0\xa4\xa6\', \'\xe0\xa4\xb0\xe0\xa5\x87\xe0\xa4\xb5\xe0\xa5\x87\xe0\xa4\xa8\xe0\xa5\x87\xe0\xa4\x82\xe0\xa4\x9f\', "\'", \'\xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xb9\xe0\xa5\x8d\xe0\xa4\xaf\xe0\xa5\x82\xe0\xa4\x9c\', \'\xe0\xa4\x97\xe0\xa5\x8d\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\xb8\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\xa6\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa4\xbe\', \',\', \'\xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8\', \'\xe0\xa4\x89\xe0\xa4\xa8\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xb0\xe0\xa5\x8b\xe0\xa4\xb2\', \'\xe0\xa4\xa8\xe0\xa4\xbf\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe\', \'\xe0\xa4\x86\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xa8\', \'\xe0\xa4\xa8\xe0\xa4\xb9\xe0\xa5\x80\xe0\xa4\x82\', \'\xe0\xa4\xa5\xe0\xa4\xbe\', \'\xe0\xa5\xa4\']\n    >>> tk = Tokenizer(lang=\'hi\', split_sen=True)\n    >>> tk.tokenize("22 \xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xb2 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\x82\xe0\xa4\xac\xe0\xa5\x87 \xe0\xa4\x87\xe0\xa4\x82\xe0\xa4\xa4\xe0\xa4\x9c\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xac\xe0\xa4\xbe\xe0\xa4\xa6 \xe0\xa4\x86\xe0\xa4\x96\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\xb9\xe0\xa5\x89\xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa5\x81\xe0\xa4\xa1 \xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x9f\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b \xe0\xa4\xa1\xe0\xa4\xbf\xe0\xa4\x95\xe0\xa5\x88\xe0\xa4\xaa\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b \xe0\xa4\x95\xe0\xa5\x8b \xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80 \xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x80 \xe0\xa4\x91\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x95\xe0\xa4\xb0 \xe0\xa4\x9f\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa5\x89\xe0\xa4\xab\xe0\xa5\x80"\n    ...             " \xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2 \xe0\xa4\x9a\xe0\xa5\x81\xe0\xa4\x95\xe0\xa5\x80 \xe0\xa4\xb9\xe0\xa5\x88\xe0\xa5\xa4 \xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xaf\xe0\xa5\x87 \xe0\xa4\x85\xe0\xa4\xb5\xe0\xa5\x89\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1 \xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80 \xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae \xe2\x80\x98\xe0\xa4\xa6 \xe0\xa4\xb0\xe0\xa5\x87\xe0\xa4\xb5\xe0\xa5\x87\xe0\xa4\xa8\xe0\xa5\x87\xe0\xa4\x82\xe0\xa4\x9f\xe2\x80\x99 \xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xb9\xe0\xa5\x8d\xe0\xa4\xaf\xe0\xa5\x82\xe0\xa4\x9c \xe0\xa4\x97\xe0\xa5\x8d\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\xb8 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\xa6\xe0\xa4\xbe\xe0\xa4\xb0 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa4\xbe, \xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8 \xe0\xa4\x89\xe0\xa4\xa8\xe0\xa4\x95\xe0\xa5\x87"\n    ...             " \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xb0\xe0\xa5\x8b\xe0\xa4\xb2 \xe0\xa4\xa8\xe0\xa4\xbf\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe \xe0\xa4\x86\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xa8 \xe0\xa4\xa8\xe0\xa4\xb9\xe0\xa5\x80\xe0\xa4\x82 \xe0\xa4\xa5\xe0\xa4\xbe\xe0\xa5\xa4 \xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae \xe0\xa4\x8f\xe0\xa4\x95 \xe0\xa4\xb8\xe0\xa5\x80\xe0\xa4\xa8 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b \xe0\xa4\x95\xe0\xa5\x8b \xe0\xa4\xad\xe0\xa5\x88\xe0\xa4\x82\xe0\xa4\xb8 \xe0\xa4\x95\xe0\xa4\xbe \xe0\xa4\x95\xe0\xa4\x9a\xe0\xa5\x8d\xe0\xa4\x9a\xe0\xa4\xbe \xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa4\xb0 \xe0\xa4\x96\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe"\n    ...             " \xe0\xa4\xaa\xe0\xa4\xa1\xe0\xa4\xbc\xe0\xa4\xbe \xe0\xa4\xa5\xe0\xa4\xbe\xe0\xa5\xa4 \xe0\xa4\x9c\xe0\xa4\xac\xe0\xa4\x95\xe0\xa4\xbf \xe0\xa4\x85\xe0\xa4\xb8\xe0\xa4\xb2 \xe0\xa4\x9c\xe0\xa4\xbf\xe0\xa4\x82\xe0\xa4\xa6\xe0\xa4\x97\xe0\xa5\x80 \xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xb5\xe0\xa5\x8b \xe0\xa4\xaa\xe0\xa5\x82\xe0\xa4\xb0\xe0\xa5\x80 \xe0\xa4\xa4\xe0\xa4\xb0\xe0\xa4\xb9 \xe0\xa4\xb6\xe0\xa4\xbe\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb9\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x80 \xe0\xa4\xb9\xe0\xa5\x88\xe0\xa4\x82\xe0\xa5\xa4 \xe0\xa4\xb9\xe0\xa4\xbe\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\x82\xe0\xa4\x95\xe0\xa4\xbf \xe0\xa4\x87\xe0\xa4\xb8 \xe0\xa4\xb8\xe0\xa5\x80\xe0\xa4\xa8 \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b \xe0\xa4\x95\xe0\xa5\x8b"\n    ...             " \xe0\xa4\xae\xe0\xa4\xbe\xe0\xa4\x82\xe0\xa4\xb8 \xe0\xa4\x9c\xe0\xa5\x88\xe0\xa4\xb8\xe0\xa5\x87 \xe0\xa4\xa6\xe0\xa4\xbf\xe0\xa4\x96\xe0\xa4\xa8\xe0\xa5\x87 \xe0\xa4\xb5\xe0\xa4\xbe\xe0\xa4\xb2\xe0\xa5\x80 \xe0\xa4\x9a\xe0\xa5\x80\xe0\xa4\x9c \xe0\xa4\xa6\xe0\xa5\x80 \xe0\xa4\x97\xe0\xa4\x88 \xe0\xa4\xa5\xe0\xa5\x80, \xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8 \xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82 \xe0\xa4\xb2\xe0\xa4\x97\xe0\xa4\xbe \xe0\xa4\x95\xe0\xa4\xbf \xe0\xa4\x90\xe0\xa4\xb8\xe0\xa4\xbe \xe0\xa4\x95\xe0\xa4\xb0\xe0\xa4\xa8\xe0\xa4\xbe \xe0\xa4\x97\xe0\xa4\xb2\xe0\xa4\xa4 \xe0\xa4\xb9\xe0\xa5\x8b\xe0\xa4\x97\xe0\xa4\xbe\xe0\xa5\xa4 \xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae \xe0\xa4\x95\xe0\xa5\x87 \xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f \xe0\xa4\x87\xe0\xa4\xae\xe0\xa5\x8d\xe0\xa4\xaa\xe0\xa5\x8b\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\x9f"\n    ...             " \xe0\xa4\x95\xe0\xa5\x80 \xe0\xa4\x97\xe0\xa4\x88 \xe0\xa4\x9a\xe0\xa5\x80\xe0\xa4\x9f\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa4\xbe\xe0\xa4\x82...")\n    [[\'22\', \'\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xb2\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\x82\xe0\xa4\xac\xe0\xa5\x87\', \'\xe0\xa4\x87\xe0\xa4\x82\xe0\xa4\xa4\xe0\xa4\x9c\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xac\xe0\xa4\xbe\xe0\xa4\xa6\', \'\xe0\xa4\x86\xe0\xa4\x96\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\xb9\xe0\xa5\x89\xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa5\x81\xe0\xa4\xa1\', \'\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x9f\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b\', \'\xe0\xa4\xa1\xe0\xa4\xbf\xe0\xa4\x95\xe0\xa5\x88\xe0\xa4\xaa\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\', \'\xe0\xa4\x95\xe0\xa5\x8b\', \'\xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80\', \'\xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x80\', \'\xe0\xa4\x91\xe0\xa4\xb8\xe0\xa5\x8d\xe0\xa4\x95\xe0\xa4\xb0\', \'\xe0\xa4\x9f\xe0\xa5\x8d\xe0\xa4\xb0\xe0\xa5\x89\xe0\xa4\xab\xe0\xa5\x80\', \'\xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\', \'\xe0\xa4\x9a\xe0\xa5\x81\xe0\xa4\x95\xe0\xa5\x80\', \'\xe0\xa4\xb9\xe0\xa5\x88\', \'\xe0\xa5\xa4\'], [\'\xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xaf\xe0\xa5\x87\', \'\xe0\xa4\x85\xe0\xa4\xb5\xe0\xa5\x89\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\', \'\xe0\xa4\x85\xe0\xa4\xaa\xe0\xa4\xa8\xe0\xa5\x80\', \'\xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae\', "\'", \'\xe0\xa4\xa6\', \'\xe0\xa4\xb0\xe0\xa5\x87\xe0\xa4\xb5\xe0\xa5\x87\xe0\xa4\xa8\xe0\xa5\x87\xe0\xa4\x82\xe0\xa4\x9f\', "\'", \'\xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xb9\xe0\xa5\x8d\xe0\xa4\xaf\xe0\xa5\x82\xe0\xa4\x9c\', \'\xe0\xa4\x97\xe0\xa5\x8d\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\xb8\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xb0\xe0\xa4\xa6\xe0\xa4\xbe\xe0\xa4\xb0\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xae\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa4\xbe\', \',\', \'\xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8\', \'\xe0\xa4\x89\xe0\xa4\xa8\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xb0\xe0\xa5\x8b\xe0\xa4\xb2\', \'\xe0\xa4\xa8\xe0\xa4\xbf\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe\', \'\xe0\xa4\x86\xe0\xa4\xb8\xe0\xa4\xbe\xe0\xa4\xa8\', \'\xe0\xa4\xa8\xe0\xa4\xb9\xe0\xa5\x80\xe0\xa4\x82\', \'\xe0\xa4\xa5\xe0\xa4\xbe\', \'\xe0\xa5\xa4\'], [\'\xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae\', \'\xe0\xa4\x8f\xe0\xa4\x95\', \'\xe0\xa4\xb8\xe0\xa5\x80\xe0\xa4\xa8\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b\', \'\xe0\xa4\x95\xe0\xa5\x8b\', \'\xe0\xa4\xad\xe0\xa5\x88\xe0\xa4\x82\xe0\xa4\xb8\', \'\xe0\xa4\x95\xe0\xa4\xbe\', \'\xe0\xa4\x95\xe0\xa4\x9a\xe0\xa5\x8d\xe0\xa4\x9a\xe0\xa4\xbe\', \'\xe0\xa4\xb2\xe0\xa5\x80\xe0\xa4\xb5\xe0\xa4\xb0\', \'\xe0\xa4\x96\xe0\xa4\xbe\xe0\xa4\xa8\xe0\xa4\xbe\', \'\xe0\xa4\xaa\xe0\xa4\xa1\xe0\xa4\xbc\xe0\xa4\xbe\', \'\xe0\xa4\xa5\xe0\xa4\xbe\', \'\xe0\xa5\xa4\'], [\'\xe0\xa4\x9c\xe0\xa4\xac\xe0\xa4\x95\xe0\xa4\xbf\', \'\xe0\xa4\x85\xe0\xa4\xb8\xe0\xa4\xb2\', \'\xe0\xa4\x9c\xe0\xa4\xbf\xe0\xa4\x82\xe0\xa4\xa6\xe0\xa4\x97\xe0\xa5\x80\', \'\xe0\xa4\xae\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xb5\xe0\xa5\x8b\', \'\xe0\xa4\xaa\xe0\xa5\x82\xe0\xa4\xb0\xe0\xa5\x80\', \'\xe0\xa4\xa4\xe0\xa4\xb0\xe0\xa4\xb9\', \'\xe0\xa4\xb6\xe0\xa4\xbe\xe0\xa4\x95\xe0\xa4\xbe\xe0\xa4\xb9\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x80\', \'\xe0\xa4\xb9\xe0\xa5\x88\xe0\xa4\x82\', \'\xe0\xa5\xa4\'], [\'\xe0\xa4\xb9\xe0\xa4\xbe\xe0\xa4\xb2\xe0\xa4\xbe\xe0\xa4\x82\xe0\xa4\x95\xe0\xa4\xbf\', \'\xe0\xa4\x87\xe0\xa4\xb8\', \'\xe0\xa4\xb8\xe0\xa5\x80\xe0\xa4\xa8\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\xaa\xe0\xa4\xb9\xe0\xa4\xb2\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa5\x8b\xe0\xa4\xa8\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\xa1\xe0\xa5\x8b\', \'\xe0\xa4\x95\xe0\xa5\x8b\', \'\xe0\xa4\xae\xe0\xa4\xbe\xe0\xa4\x82\xe0\xa4\xb8\', \'\xe0\xa4\x9c\xe0\xa5\x88\xe0\xa4\xb8\xe0\xa5\x87\', \'\xe0\xa4\xa6\xe0\xa4\xbf\xe0\xa4\x96\xe0\xa4\xa8\xe0\xa5\x87\', \'\xe0\xa4\xb5\xe0\xa4\xbe\xe0\xa4\xb2\xe0\xa5\x80\', \'\xe0\xa4\x9a\xe0\xa5\x80\xe0\xa4\x9c\', \'\xe0\xa4\xa6\xe0\xa5\x80\', \'\xe0\xa4\x97\xe0\xa4\x88\', \'\xe0\xa4\xa5\xe0\xa5\x80\', \',\', \'\xe0\xa4\xb2\xe0\xa5\x87\xe0\xa4\x95\xe0\xa4\xbf\xe0\xa4\xa8\', \'\xe0\xa4\x89\xe0\xa4\xa8\xe0\xa5\x8d\xe0\xa4\xb9\xe0\xa5\x87\xe0\xa4\x82\', \'\xe0\xa4\xb2\xe0\xa4\x97\xe0\xa4\xbe\', \'\xe0\xa4\x95\xe0\xa4\xbf\', \'\xe0\xa4\x90\xe0\xa4\xb8\xe0\xa4\xbe\', \'\xe0\xa4\x95\xe0\xa4\xb0\xe0\xa4\xa8\xe0\xa4\xbe\', \'\xe0\xa4\x97\xe0\xa4\xb2\xe0\xa4\xa4\', \'\xe0\xa4\xb9\xe0\xa5\x8b\xe0\xa4\x97\xe0\xa4\xbe\', \'\xe0\xa5\xa4\'], [\'\xe0\xa4\xab\xe0\xa4\xbf\xe0\xa4\xb2\xe0\xa5\x8d\xe0\xa4\xae\', \'\xe0\xa4\x95\xe0\xa5\x87\', \'\xe0\xa4\xb2\xe0\xa4\xbf\xe0\xa4\x8f\', \'\xe0\xa4\x87\xe0\xa4\xae\xe0\xa5\x8d\xe0\xa4\xaa\xe0\xa5\x8b\xe0\xa4\xb0\xe0\xa5\x8d\xe0\xa4\x9f\', \'\xe0\xa4\x95\xe0\xa5\x80\', \'\xe0\xa4\x97\xe0\xa4\x88\', \'\xe0\xa4\x9a\xe0\xa5\x80\xe0\xa4\x9f\xe0\xa4\xbf\xe0\xa4\xaf\xe0\xa4\xbe\xe0\xa4\x82\', \'...\']]\n\n\nFrom Console\n^^^^^^^^^^^^\n\n.. parsed-literal::\n\n    polyglot-tokenizer --h\n\n    usage: polyglot-tokenizer [-h] [-v] [-i] [-s] [-t] [-o] [-l]\n    \n    Tokenizer for world\'s most spoken languages\n\n    \n    optional arguments:\n      -h, --help            show this help message and exit\n      -v, --version         show program\'s version number and exit\n      -i , --input          <input-file>\n      -s, --split-sentences\n                            set this flag to apply sentence segmentation\n      -t, --social-media-test\n                            set this flag if the input file contains social media\n                            text like twitter, facebook and whatsapp\n      -o , --output         <output-file>\n      -l , --language       select language (2 letter ISO-639 code) {hi, ur, bn,\n                            as, gu, ml, pa, te, ta, kn, or, mr, cu, myv, nn, yi,\n                            ne, bo, br, ks, en, es, ca, cs, de, el, en, fi, da,\n                            eu, kok, nb, uz, fr, ga, hu, is, it, lt, lv, nl, pl,\n                            pt, ro, ru, sk, bm, yue, mk, ku, sl, sv, zh, et, fo,\n                            gl, hsb, af, ar, be, hy, bg, ka, ug, hr, mn, tk, kk,\n                            ky, la, no, fa, uk, tl, tr, vi, yo, ko, got, ckb, he,\n                            id, sr}\n\n    Example ::\n\n    polyglot-tokenizer < raw_file.txt -l en -s > tokenized.txt\n\n\n\n\n',
    'author': 'irshadbhat',
    'author_email': 'bhatirshad127@gmail.com',
    'url': 'https://github.com/irshadbhat/polyglot-tokenizer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
}


setup(**setup_kwargs)
